import React, { useRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import MoleculeProgressStep, { STATUSES } from './components/MoleculeProgressStep';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_CONTENT = BASE_CLASS + "-content";
var CLASS_COMPRESSED_INFO = BASE_CLASS + "-compressedInfo";
var CLASS_VERTICAL = BASE_CLASS + "--vertical";
var CLASS_COMPRESSED = BASE_CLASS + "--compressed";

var MoleculeProgressSteps = function MoleculeProgressSteps(_ref) {
  var _cx;

  var vertical = _ref.vertical,
      children = _ref.children,
      iconStepDone = _ref.iconStepDone,
      compressed = _ref.compressed;
  var activeStepContent = useRef();
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_VERTICAL] = vertical, _cx[CLASS_COMPRESSED] = compressed, _cx));

  var getCompressedInfoSteps = function getCompressedInfoSteps() {
    var childrenNodes = React.Children.toArray(children);
    var totalSteps = childrenNodes.length;

    var _childrenNodes$reduce = childrenNodes.reduce(function (acc, child, index) {
      var status = child.props.status;
      if (status === STATUSES.ACTIVE) acc = [child.props.label, index + 1];
      return acc;
    }, []),
        activeLabel = _childrenNodes$reduce[0],
        numActiveStep = _childrenNodes$reduce[1];

    var stepPositionInfo = numActiveStep + "/" + totalSteps;
    return stepPositionInfo + ": " + activeLabel;
  };

  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index, children) {
    var _child$props = child.props,
        iconChild = _child$props.icon,
        iconActive = _child$props.iconActive,
        status = _child$props.status,
        childrenChild = _child$props.children;
    var totalChildren = children.length;
    var numStep = index + 1;
    var lastStep = index >= totalChildren - 1;
    var isVisited = status === STATUSES.VISITED;
    var isActive = status === STATUSES.ACTIVE;
    var icon = iconChild;
    if (isVisited) icon = iconStepDone;

    if (isActive) {
      icon = iconActive || iconChild;
      activeStepContent.current = childrenChild;
    }

    return React.cloneElement(child, {
      numStep: numStep,
      lastStep: lastStep,
      icon: icon,
      compressed: compressed
    });
  });
  return React.createElement("div", {
    className: className
  }, compressed && React.createElement("p", {
    className: CLASS_COMPRESSED_INFO
  }, getCompressedInfoSteps()), React.createElement("div", {
    className: CLASS_STEPS
  }, extendedChildren), React.createElement("div", {
    className: CLASS_CONTENT
  }, activeStepContent.current));
};

MoleculeProgressSteps.displayName = 'MoleculeProgressSteps';
export default MoleculeProgressSteps;
export { MoleculeProgressStep, STATUSES };